<?php

/**
 * @file
 * Administrative page callbacks for the BirdSeed module.
 */

/**
 * BirdSeed settings form.
 */
function birdseed_admin_settings_form($form_state) {
  $form = array();

  $settings = birdseed_get_settings();
  $form['birdseed_data_token'] = array(
    '#parents' => array('birdseed_settings', 'birdseed_data_token'),
    '#title' => t('BirdSeed data-token'),
    '#type' => 'textfield',
    '#default_value' => $settings['birdseed_data_token'],
    '#size' => 38,
    '#maxlength' => 38,
    '#required' => TRUE,
    '#description' => t('Your BirdSeed data-token can be found in your script <code>data-token="<b>95bde5f4321ff929a69a53a36ea9d123</b>"</code> where <code><b>95bde5f4321ff929a69a53a36ea9d123</b></code> is your BirdSeed data-token.'),
  );
  $form['birdseed_status'] = array(
    '#parents' => array('birdseed_settings', 'birdseed_status'),
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#default_value' => $settings['birdseed_status'],
    '#description' => 'Uncheck if you want to disable BirdSeed widget for some reason.',
  );

  $form['tracking'] = array(
    '#type' => 'vertical_tabs',
  );

  $visibility = $settings['birdseed_visibility_pages'];
  $pages = $settings['birdseed_pages'];

  $form['tracking']['page_display'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pages'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  if ($visibility == 2) {
    $form['tracking']['page_display'] = array();
    $form['tracking']['page_display']['birdseed_visibility_pages'] = array('#type' => 'value', '#value' => 2);
    $form['tracking']['page_display']['birdseed_pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(
      t('Every page except the listed pages'),
      t('The listed pages only'),
    );
    $description_args = array(
      '%blog' => 'blog',
      '%blog-wildcard' => 'blog/*',
      '%front' => '<front>',
    );
    $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", $description_args);
    $title = t('Pages');
    $form['tracking']['page_display']['birdseed_visibility_pages'] = array(
      '#parents' => array('birdseed_settings', 'birdseed_visibility_pages'),
      '#type' => 'radios',
      '#title' => t('Add BirdSeed script to specific pages'),
      '#options' => $options,
      '#default_value' => $visibility,
    );
    $form['tracking']['page_display']['birdseed_pages'] = array(
      '#parents' => array('birdseed_settings', 'birdseed_pages'),
      '#type' => 'textarea',
      '#title' => $title,
      '#title_display' => 'invisible',
      '#default_value' => $pages,
      '#description' => $description,
      '#rows' => 10,
    );
  }

  // Render the role overview.
  $form['tracking']['role_display'] = array(
    '#type' => 'fieldset',
    '#title' => t('Roles'),
  );

  $form['tracking']['role_display']['birdseed_visibility_roles'] = array(
    '#parents' => array('birdseed_settings', 'birdseed_visibility_roles'),
    '#type' => 'radios',
    '#title' => t('Add BirdSeed script for specific roles'),
    '#options' => array(
      t('Add to the selected roles only'),
      t('Add to every role except the selected ones'),
    ),
    '#default_value' => $settings['birdseed_visibility_roles'],
  );

  $role_options = array_map('check_plain', user_roles());
  $form['tracking']['role_display']['birdseed_roles'] = array(
    '#parents' => array('birdseed_settings', 'birdseed_roles'),
    '#type' => 'checkboxes',
    '#title' => t('Roles'),
    '#default_value' => $settings['birdseed_roles'],
    '#options' => $role_options,
    '#description' => t('If none of the roles are selected, all users will be tracked. If a user has any of the roles checked, that user will be tracked (or excluded, depending on the setting above).'),
  );

  return system_settings_form($form);
}
